@@ -43,6 +43,7 @@
 #include "eog-thumbnail.h"
 
 #include <unistd.h>
+#include <string.h>
 
 #include <glib.h>
 #include <glib-object.h>
@@ -222,7 +223,7 @@ eog_image_class_init (EogImageClass *klass)
 
 	signals[SIGNAL_SAVE_PROGRESS] = 
 		g_signal_new ("save-progress",
-			      G_TYPE_OBJECT,
+			      EOG_TYPE_IMAGE,
 			      G_SIGNAL_RUN_LAST,
 			      G_STRUCT_OFFSET (EogImageClass, save_progress),
 			      NULL, NULL,
@@ -777,7 +778,7 @@ eog_image_set_exif_data (EogImage *img, EogMetadataReader *md_reader)
 #endif
 }
 
-/**
+/*
  * Attempts to get the image dimensions from the thumbnail.
  * Returns FALSE if this information is not found.
  **/
@@ -1536,11 +1537,11 @@ eog_image_copy_file (EogImageSaveInfo *source, EogImageSaveInfo *target, GError
 		if (ioerror->code == G_IO_ERROR_EXISTS) {
 			g_set_error (error, EOG_IMAGE_ERROR,
 				     EOG_IMAGE_ERROR_FILE_EXISTS,
-				     ioerror->message);
+				     "%s", ioerror->message);
 		} else {
 		g_set_error (error, EOG_IMAGE_ERROR,
 			     EOG_IMAGE_ERROR_VFS, 
-			     ioerror->message);
+			     "%s", ioerror->message);
 		}
 		g_error_free (ioerror);
 	}
